@@ -212,9 +212,9 @@ class Parser(object):
 
             # compress file and check if return code is not zero
             # when return code is not zero it means yuicompressor failed to run
-            (return_code, out_str) = utils.compress(source_file,
-                                                    destination_file,
-                                                    **kw)
+            (return_code, out_str) = utils.yuicompress(source_file,
+                                                       destination_file,
+                                                       **kw)
         else:
             LOG.info('Generating file %s', destination_file)
             shutil.copy(source_file, destination_file)
